/*
 * PrimitiveRegistrator.cpp
 *
 *  Created on: 11. 7. 2017
 *	  Author: Jan Travnicek
 */

#include <abstraction/CastRegistry.hpp>
#include <abstraction/XmlFileWriterRegistry.hpp>
#include <abstraction/XmlParserRegistry.hpp>
#include <abstraction/NormalizeRegistry.hpp>
#include <abstraction/ValuePrinterRegistry.hpp>
#include <abstraction/ImmediateRegistry.hpp>
#include <abstraction/ContainerRegistry.hpp>

#include <primitive/Double.h>
#include <primitive/Integer.h>
#include <primitive/Unsigned.h>
#include <primitive/Bool.h>
#include <primitive/UnsignedLong.h>
#include <primitive/String.h>

#include <container/ObjectsVector.h>
#include <container/ObjectsSet.h>
#include <container/ObjectsMap.h>

#include <common/DefaultStateType.h>
#include <common/DefaultSymbolType.h>
#include <common/DefaultRankType.h>

#include <common/ranked_symbol.hpp>
#include <alphabet/RankedSymbol.h>

namespace abstraction {

class PrimitiveRegistrator2 {
public:
	PrimitiveRegistrator2 ( ) {
		abstraction::XmlFileWriterRegistry::registerXmlFileWriter < ext::map < DefaultSymbolType, size_t > > ( );
		abstraction::XmlFileWriterRegistry::registerXmlFileWriter < ext::map < common::ranked_symbol < DefaultSymbolType, DefaultRankType >, size_t > > ( );

		abstraction::ContainerRegistry::registerSet < common::ranked_symbol < DefaultSymbolType, DefaultRankType > > ( "ranked_symbol" );
		abstraction::XmlParserRegistry::registerXmlParser < common::ranked_symbol < DefaultSymbolType, DefaultRankType > > ( "ranked_symbol" );

		abstraction::XmlParserRegistry::registerXmlParser < DefaultStateType > ( "DefaultStateType" );
		abstraction::XmlFileWriterRegistry::registerXmlFileWriter < DefaultStateType > ( );
	}
};

auto primitiveRegistrator2 = PrimitiveRegistrator2 ( );

} /* namespace abstraction */
